@@ -11,10 +11,6 @@ import (
 	"github.com/lmorg/murex/lang/types"
 )
 
-func init() {
-	lang.DefineMethod("@[", CmdRange, types.ReadArray, types.WriteArray)
-}
-
 const usage = "\nUsage: [start..end] / [start..end]se\n(start or end can be omitted)"
 
 // if additional ranges are added here, they will also need to be added to
