@@ -6,6 +6,7 @@ import (
 	"errors"
 	"io"
 	"net/smtp"
+	"os"
 	"sync"
 
 	"github.com/lmorg/murex/config"
@@ -33,6 +34,10 @@ type Mail struct {
 	recipients []string
 }
 
+func (m *Mail) File() *os.File {
+	return nil
+}
+
 // Read is an empty method because you cannot read a sent email
 func (m *Mail) Read(p []byte) (int, error) {
 	return 0, nil
