@@ -2,10 +2,10 @@ package term
 
 import (
 	"errors"
+	"os"
 
 	"github.com/lmorg/murex/builtins/pipes/streams"
 	"github.com/lmorg/murex/lang/stdio"
-	"github.com/lmorg/murex/lang/tty"
 )
 
 // Terminal: Standard In
@@ -24,12 +24,16 @@ func NewIn(dataType string) stdio.Io {
 }
 
 func backgroundRead(t *In) {
-	_, err := t.ReadFrom(tty.Stdin)
+	_, err := t.ReadFrom(os.Stdin)
 	if err != nil {
-		tty.Stderr.WriteString("Error reading from STDIN: " + err.Error())
+		os.Stderr.WriteString("Error reading from STDIN: " + err.Error())
 	}
 }
 
+func (t *In) File() *os.File {
+	return nil
+}
+
 // Write is the io.Writer() interface for term
 func (t *In) Write(_ []byte) (int, error) {
 	return 0, errors.New("attempting to write to a readonly STDIN interface: Write()")
