@@ -3,6 +3,7 @@ package generic
 import (
 	"bufio"
 	"context"
+	"fmt"
 
 	"github.com/lmorg/murex/lang/stdio"
 	"github.com/lmorg/murex/lang/types"
@@ -20,7 +21,11 @@ func readArray(ctx context.Context, read stdio.Io, callback func([]byte)) error
 		}
 	}
 
-	return scanner.Err()
+	err := scanner.Err()
+	if err != nil {
+		return fmt.Errorf("error while reading a %s array: %s", types.Generic, err.Error())
+	}
+	return nil
 }
 
 func readArrayWithType(ctx context.Context, read stdio.Io, callback func(interface{}, string)) error {
@@ -35,5 +40,9 @@ func readArrayWithType(ctx context.Context, read stdio.Io, callback func(interfa
 		}
 	}
 
-	return scanner.Err()
+	err := scanner.Err()
+	if err != nil {
+		return fmt.Errorf("error while reading a %s array: %s", types.Generic, err.Error())
+	}
+	return nil
 }
