@@ -2,7 +2,9 @@ package debug
 
 import (
 	"encoding/json"
+	"fmt"
 	"log"
+	"os"
 )
 
 // Enabled is a flag used for debugging murex code. This can be enabled at
@@ -16,6 +18,13 @@ func Log(data ...interface{}) {
 	}
 }
 
+// Logf writes a debug message using [fmt.Printf] arguments.
+func Logf(format string, v ...interface{}) {
+	if Enabled {
+		log.Println(fmt.Sprintf(format, v...))
+	}
+}
+
 // Json encode an object then write it as a debug message
 func Json(context string, data interface{}) {
 	if Enabled {
@@ -34,3 +43,13 @@ func Dump() interface{} {
 		Debug: Enabled,
 	}
 }
+
+func LogWriter(path string) error {
+	f, err := os.OpenFile(path, os.O_CREATE|os.O_APPEND|os.O_RDWR, 0666)
+	if err != nil {
+		return err
+	}
+	log.SetOutput(f)
+	log.SetPrefix(fmt.Sprintf("[PID: %d] ", os.Getpid()))
+	return nil
+}
