@@ -4,10 +4,24 @@ import (
 	"fmt"
 )
 
+type UnmarshallerT func(*Process) (any, error)
+
+var (
+	// _unmarshallers defines the Go functions for converting a murex data type into a Go interface
+	_unmarshallers = make(map[string]UnmarshallerT)
+)
+
+func RegisterUnmarshaller(dataType string, unmarshaller UnmarshallerT) {
+	if _unmarshallers[dataType] != nil {
+		panic(fmt.Sprintf("unmarshaller already exists for %s", dataType))
+	}
+	_unmarshallers[dataType] = unmarshaller
+}
+
 // UnmarshalData is a global unmarshaller which should be called from within
 // murex builtin commands (etc).
 // See docs/apis/marshaldata.md for more details
-func UnmarshalData(p *Process, dataType string) (v interface{}, err error) {
+func UnmarshalData(p *Process, dataType string) (v any, err error) {
 	// This is one of the very few maps in Murex which isn't hidden behind a sync
 	// lock of one description or other. The rational is that even mutexes can
 	// add a noticeable overhead on the performance of tight loops and I expect
@@ -16,11 +30,12 @@ func UnmarshalData(p *Process, dataType string) (v interface{}, err error) {
 	// murex is effectively single threaded). So there shouldn't be any data-
 	// races -- PROVIDING developers strictly follow the pattern of only writing
 	// to this map within init() func's.
-	if Unmarshallers[dataType] == nil {
+
+	if _unmarshallers[dataType] == nil {
 		return nil, fmt.Errorf("unknown data type. I don't know how to unmarshal `%s`", dataType)
 	}
 
-	v, err = Unmarshallers[dataType](p)
+	v, err = _unmarshallers[dataType](p)
 	if err != nil {
 		return nil, fmt.Errorf("[%s unmarshaller] %s", dataType, err.Error())
 	}
@@ -33,6 +48,7 @@ func UnmarshalDataBuffered(parent *Process, b []byte, dataType string) (interfac
 	defer fork.Kill()
 
 	_, err := fork.Stdin.Write(b)
+	defer fork.Stdin.Close()
 	if err != nil {
 		return nil, fmt.Errorf("cannot write value to unmarshaller's buffer: %s", err.Error())
 	}
