@@ -12,6 +12,7 @@ import (
 	"github.com/lmorg/murex/lang/state"
 	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/utils/consts"
+	"github.com/lmorg/murex/utils/which"
 )
 
 const (
@@ -29,39 +30,52 @@ var (
 	//termOut     = reflect.TypeOf(new(term.Out)).String()
 )
 
+func forceTTY(p *Process) bool {
+	v, err := p.Config.Get("proc", "force-tty", types.Boolean)
+	if err != nil {
+		return false
+	}
+	return v.(bool)
+}
+
 // External executes an external process.
 func External(p *Process) error {
-	if err := execute(p); err != nil {
-		_, cmd := p.Exec.Get()
-		if cmd != nil {
-			p.ExitNum = cmd.ProcessState.ExitCode()
-		} else {
-			p.ExitNum = 1
-		}
+	err := execute(p)
+	if err != nil {
+		//if p.SystemProcess.External() {
+		p.ExitNum = p.SystemProcess.ExitNum()
+		//} else {
+		//	p.ExitNum = 1
+		//}
 		return err
-
 	}
+
 	return nil
 }
 
 func execute(p *Process) error {
-	exeName, parameters, err := getCmdTokens(p)
-	if err != nil {
-		return err
+	argv := osExecGetArgv(p)
+	if len(argv) == 0 {
+		return fmt.Errorf("no parameters specified for `exec`\nExpecting a name of command to run")
 	}
-	cmd := exec.Command(exeName, parameters...)
+
+	return execFork(p, argv)
+}
+
+func execFork(p *Process, argv []string) error {
+	cmd := exec.Command(which.WhichIgnoreFail(argv[0]), argv[1:]...)
 
 	if p.HasCancelled() {
 		return nil
 	}
-
-	//ctxCancel := p.Kill
 	p.Kill = func() {
 		if !debug.Enabled {
 			defer func() { recover() }() // I don't care about errors in this instance since we are just killing the proc anyway
 		}
 
-		//ctxCancel()
+		//if p.SystemProcess.ForcedTTY() {
+		UnixPidToFg(nil)
+		//}
 		err := cmd.Process.Signal(syscall.SIGTERM)
 		if err != nil {
 			if err.Error() == os.ErrProcessDone.Error() {
@@ -69,7 +83,7 @@ func execute(p *Process) error {
 			}
 			name, _ := p.Args()
 			os.Stderr.WriteString(
-				fmt.Sprintf("\nError sending SIGTERM to `%s`: %s\n", name, err.Error()))
+				fmt.Sprintf("\n!!! Error sending SIGTERM to `%s`: %s\n", name, err.Error()))
 		}
 	}
 
@@ -90,20 +104,20 @@ func execute(p *Process) error {
 		cmd.Env = append(os.Environ(), envMurexPid, envMethodFalse, envBackgroundTrue, envDataType+p.Stdin.GetDataType())
 	default:
 		cmd.Stdin = os.Stdin
-		cmd.Env = append(os.Environ(), envMurexPid, envMethodFalse, envBackgroundFalse, envDataType+p.Stdin.GetDataType())
+		cmd.Env = append(os.Environ(), envMurexPid, envMethodFalse, envBackgroundFalse, envDataType+"<term>")
 	}
 
-	if len(p.Exec.Env) > 0 {
-		for i := range p.Exec.Env {
-			if !strings.Contains(p.Exec.Env[i], "=") {
-				v, err := p.Variables.GetString(p.Exec.Env[i])
+	if len(p.Envs) > 0 {
+		for i := range p.Envs {
+			if !strings.Contains(p.Envs[i], "=") {
+				v, err := p.Variables.GetString(p.Envs[i])
 				if err != nil {
 					continue
 				}
-				p.Exec.Env[i] += "=" + v
+				p.Envs[i] += "=" + v
 			}
 		}
-		cmd.Env = append(cmd.Env, p.Exec.Env...)
+		cmd.Env = append(cmd.Env, p.Envs...)
 	}
 
 	// ***
@@ -112,13 +126,7 @@ func execute(p *Process) error {
 
 	if p.Stdout.IsTTY() {
 		// If Stdout is a TTY then set the appropriate syscalls to allow the calling program to own the TTY....
-		//osSyscalls(cmd, int(p.ttyout.Fd()))
-		//osSyscalls(cmd, int(os.Stdin.Fd()))
-		//if reflect.TypeOf(p.Stdout).String() == termOut {
-		//	osSyscalls(cmd, int(p.ttyout.Fd()))
-		//	cmd.Stdout = p.ttyout
-		//} else {
-		osSyscalls(cmd, int(p.Stdout.File().Fd()))
+		cmd.SysProcAttr = unixProcAttrFauxTTY()
 		cmd.Stdout = p.Stdout.File()
 		//}
 	} else {
@@ -171,6 +179,8 @@ func execute(p *Process) error {
 		//}
 	}
 
+	p.SystemProcess.Set(&sysProcT{cmd})
+
 	// ***
 	// Get murex data type
 	// ***
@@ -200,13 +210,12 @@ func execute(p *Process) error {
 
 	/////////
 
-	p.Exec.Set(cmd.Process.Pid, cmd)
-
 	/*if err := mxdtW.Close(); err != nil {
 		tty.Stderr.WriteString("error closing murex data type output file write pipe:" + err.Error() + "\n")
 	}*/
 
-	if err := cmd.Wait(); err != nil {
+	err := cmd.Wait()
+	if err != nil {
 		if !strings.HasPrefix(err.Error(), "signal:") {
 			//mxdtR.Close()
 			return err
@@ -217,10 +226,10 @@ func execute(p *Process) error {
 	return nil
 }
 
-func forceTTY(p *Process) bool {
-	v, err := p.Config.Get("proc", "force-tty", types.Boolean)
-	if err != nil {
-		return false
-	}
-	return v.(bool)
-}
+type sysProcT struct{ cmd *exec.Cmd }
+
+func (sp *sysProcT) Pid() int                   { return sp.cmd.Process.Pid }
+func (sp *sysProcT) ExitNum() int               { return sp.cmd.ProcessState.ExitCode() }
+func (sp *sysProcT) Kill() error                { return sp.cmd.Process.Kill() }
+func (sp *sysProcT) Signal(sig os.Signal) error { return sp.cmd.Process.Signal(sig) }
+func (sp *sysProcT) State() *os.ProcessState    { return sp.cmd.ProcessState }
