@@ -21,10 +21,7 @@ func expEqualFunc(tree *ParserT) (*primitives.DataType, error) {
 		return nil, err
 	}
 
-	return &primitives.DataType{
-		Primitive: primitives.Boolean,
-		Value:     lv == rv,
-	}, nil
+	return primitives.NewPrimitive(primitives.Boolean, lv == rv), nil
 }
 
 func expEqualTo(tree *ParserT) error {
@@ -46,7 +43,7 @@ func expNotEqualTo(tree *ParserT) error {
 		return err
 	}
 
-	dt.Value = !dt.Value.(bool)
+	dt.NotValue()
 
 	return tree.foldAst(&astNodeT{
 		key: symbols.Boolean,
@@ -56,36 +53,67 @@ func expNotEqualTo(tree *ParserT) error {
 }
 
 func expLike(tree *ParserT, eq bool) error {
-	left, right, err := tree.getLeftAndRightSymbols()
+	leftNode, rightNode, err := tree.getLeftAndRightSymbols()
 	if err != nil {
 		return err
 	}
 
-	leftL, err := types.ConvertGoType(left.dt.Value, types.String)
+	left, err := leftNode.dt.GetValue()
+	if err != nil {
+		return err
+	}
+
+	right, err := rightNode.dt.GetValue()
+	if err != nil {
+		return err
+	}
+
+	lv, rv := left.Value, right.Value
+	// convert to number, if possible
+	if left.Primitive == primitives.String {
+		if v, err := types.ConvertGoType(left.Value, types.Number); err == nil {
+			lv = v
+		}
+	}
+	if right.Primitive == primitives.String {
+		if v, err := types.ConvertGoType(right.Value, types.Number); err == nil {
+			rv = v
+		}
+	}
+
+	// convert to string
+	lv, err = types.ConvertGoType(lv, types.String)
+	if err != nil {
+		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
+	}
+	rv, err = types.ConvertGoType(rv, types.String)
 	if err != nil {
 		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
 	}
 
-	rightL, err := types.ConvertGoType(right.dt.Value, types.String)
-	if err != nil {
-		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
-	}
-
-	leftL = strings.TrimSpace(strings.ToLower(leftL.(string)))
-	rightL = strings.TrimSpace(strings.ToLower(rightL.(string)))
+	// trim and lowercase string
+	lv = strings.TrimSpace(strings.ToLower(lv.(string)))
+	rv = strings.TrimSpace(strings.ToLower(rv.(string)))
 
 	return tree.foldAst(&astNodeT{
 		key: symbols.Boolean,
 		pos: tree.ast[tree.astPos].pos,
-		dt: &primitives.DataType{
-			Primitive: primitives.Boolean,
-			Value:     (leftL == rightL) == eq,
-		},
+		dt:  primitives.NewPrimitive(primitives.Boolean, (lv == rv) == eq),
 	})
 }
 
 func expRegexp(tree *ParserT, eq bool) error {
-	left, right, err := tree.getLeftAndRightSymbols()
+	leftNode, rightNode, err := tree.getLeftAndRightSymbols()
+	if err != nil {
+		return err
+	}
+
+	left, err := leftNode.dt.GetValue()
+	if err != nil {
+		return err
+	}
+
+	right, err := rightNode.dt.GetValue()
 	if err != nil {
 		return err
 	}
@@ -93,38 +121,35 @@ func expRegexp(tree *ParserT, eq bool) error {
 	var lv string
 
 	if tree.StrictTypes() {
-		if left.dt.Primitive != primitives.String {
-			return raiseError(tree.expression, left, 0, fmt.Sprintf(
+		if left.Primitive != primitives.String {
+			return raiseError(tree.expression, leftNode, 0, fmt.Sprintf(
 				"left side should be %s, instead received %s",
-				primitives.String, left.dt.Primitive))
+				primitives.String, left.Primitive))
 		}
-		lv = left.dt.Value.(string)
+		lv = left.Value.(string)
 	} else {
-		v, err := types.ConvertGoType(left.dt.Value, types.String)
+		v, err := types.ConvertGoType(left.Value, types.String)
 		if err != nil {
 			return fmt.Errorf("cannot convert left side %s into a %s: %s",
-				left.dt.Primitive, primitives.String, err.Error())
+				left.Primitive, primitives.String, err.Error())
 		}
 		lv = v.(string)
 	}
 
-	if right.dt.Primitive != primitives.String {
-		return raiseError(tree.expression, right, 0, fmt.Sprintf(
+	if right.Primitive != primitives.String {
+		return raiseError(tree.expression, rightNode, 0, fmt.Sprintf(
 			"right side should be a regexp expression, instead received %s",
-			right.dt.Primitive))
+			right.Primitive))
 	}
 
-	rx, err := regexp.Compile(right.dt.Value.(string))
+	rx, err := regexp.Compile(right.Value.(string))
 	if err != nil {
-		return raiseError(tree.expression, right, 0, err.Error())
+		return raiseError(tree.expression, rightNode, 0, err.Error())
 	}
 
 	return tree.foldAst(&astNodeT{
 		key: symbols.Boolean,
 		pos: tree.ast[tree.astPos].pos,
-		dt: &primitives.DataType{
-			Primitive: primitives.Boolean,
-			Value:     rx.MatchString(lv) == eq,
-		},
+		dt:  primitives.NewPrimitive(primitives.Boolean, rx.MatchString(lv) == eq),
 	})
 }
