@@ -81,13 +81,29 @@ func TestParseQuoteSingle(t *testing.T) {
 				input:    `'foo-$bar-bar'`,
 				expected: `foo-$bar-bar`,
 			},
+			{
+				input:    `'foo-$(bar)-bar'`,
+				expected: `foo-$(bar)-bar`,
+			},
 			{
 				input:    `'foo-@bar-bar'`,
 				expected: `foo-@bar-bar`,
 			},
 			{
-				input:    `'\s\t\r\n'`,
-				expected: `\s\t\r\n`,
+				input:    `'\s'`,
+				expected: `\s`,
+			},
+			{
+				input:    `'\t'`,
+				expected: `\t`,
+			},
+			{
+				input:    `'\r'`,
+				expected: `\r`,
+			},
+			{
+				input:    `'\n'`,
+				expected: `\n`,
 			},
 		},
 	}
