@@ -8,7 +8,7 @@ import (
 
 	"github.com/lmorg/murex/lang/ref"
 	"github.com/lmorg/murex/lang/types"
-	"github.com/lmorg/murex/utils/readline"
+	"github.com/lmorg/readline/v4"
 )
 
 // MurexFuncs is a table of murex functions
