@@ -15,18 +15,13 @@ func listExes(path string, exes map[string]bool) {
 	listExesWindows(path, exes)
 }
 
-func matchExes(s string, exes map[string]bool, includeColon bool) (items []string) {
-	colon := ""
-	if includeColon {
-		colon = ":"
-	}
-
+func matchExes(s string, exes map[string]bool) (items []string) {
 	for name := range exes {
 		lc := strings.ToLower(s)
 		if strings.HasPrefix(strings.ToLower(name), lc) {
 			switch {
-			case isSpecialBuiltin(name):
-				items = append(items, name[len(s):]+colon)
+			//case isSpecialBuiltin(name):
+			//	items = append(items, name[len(s):])
 			case consts.NamedPipeProcName == name:
 				// do nothing
 			default:
