@@ -13,6 +13,7 @@ import (
 	"github.com/lmorg/murex/shell/variables"
 	"github.com/lmorg/murex/utils"
 	"github.com/lmorg/murex/utils/ansi"
+	"github.com/lmorg/murex/utils/lists"
 	"github.com/lmorg/murex/utils/parser"
 )
 
@@ -29,6 +30,9 @@ func hintText(line []rune, pos int) []rune {
 
 	if cmd == "cd" && len(pt.Parameters) > 0 && len(pt.Parameters[0]) > 0 {
 		path := variables.ExpandString(pt.Parameters[0])
+		if path == "-" {
+			return hintCdPrevious()
+		}
 		path = utils.NormalisePath(path)
 		return []rune("Change directory: " + path)
 	}
@@ -48,6 +52,28 @@ func hintText(line []rune, pos int) []rune {
 	return HintCodeBlock()
 }
 
+func hintCdPreviousPwdHistErr(err error) []rune {
+	return []rune(fmt.Sprintf("unable to decode $PWDHIST: %s", err.Error()))
+}
+
+func hintCdPrevious() []rune {
+	pwdHist, err := lang.ShellProcess.Variables.GetValue("PWDHIST")
+	if err != nil {
+		return hintCdPreviousPwdHistErr(err)
+	}
+
+	pwdStrings, err := lists.GenericToString(pwdHist)
+	if err != nil {
+		return hintCdPreviousPwdHistErr(err)
+	}
+
+	if len(pwdStrings) < 2 {
+		return []rune("already at first directory in $PWDHIST")
+	}
+
+	return []rune(pwdStrings[len(pwdStrings)-2])
+}
+
 func hintExpandVariables(line []rune) []rune {
 	r, err := history.ExpandVariables(line, Prompt)
 	if err != nil {
