@@ -1,12 +1,15 @@
-package test
+package test_test
 
 import (
 	"testing"
+
+	_ "github.com/lmorg/murex/lang/expressions"
+	"github.com/lmorg/murex/test"
 )
 
 // TestBool proves the boolean test framework works
 func TestBool(t *testing.T) {
-	tests := []BooleanTest{
+	tests := []test.BooleanTest{
 		{
 			Block:  "true",
 			Result: true,
@@ -17,5 +20,5 @@ func TestBool(t *testing.T) {
 		},
 	}
 
-	RunBooleanTests(tests, t)
+	test.RunBooleanTests(tests, t)
 }
