@@ -14,6 +14,7 @@ type plan struct {
 	path     string
 	change   string
 	expected string
+	error    bool
 }
 
 func alterTest(t *testing.T, test *plan) {
@@ -331,3 +332,16 @@ func TestUpdateArrayFloat(t *testing.T) {
 
 	alterTest(t, &test)
 }
+
+// https://github.com/lmorg/murex/issues/850
+func TestUpdateIssue850(t *testing.T) {
+	test := plan{
+		original: `{}`,
+		path:     "/",
+		change:   `{ "key": [{"hello": "world"}] }`,
+		expected: `{"":{"key":[{"hello":"world"}]}}`,
+	}
+
+	alterTest(t, &test)
+}
+
