@@ -5,6 +5,7 @@ package cache
 
 import (
 	"context"
+	"sort"
 	"time"
 )
 
@@ -32,10 +33,28 @@ func trimDb(_ context.Context, _ string) ([]string, error) {
 	return nil, nil
 }
 
-func flushDb(_ context.Context, _ string) ([]string, error) {
+func clearDb(_ context.Context, _ string) ([]string, error) {
 	return nil, nil
 }
 
 func CloseDb() {
 	// do nothing
 }
+
+func DbPath() string  { return "" }
+func DbEnabled() bool { return false }
+
+func ListNamespaces() []string {
+	var (
+		ret = make([]string, len(cache))
+		i   int
+	)
+
+	for namespace := range cache {
+		ret[i] = namespace
+		i++
+	}
+
+	sort.Strings(ret)
+	return ret
+}
